import { useCallback } from 'react';
import useSelectInputProps from './useSelectInputProps';
import useCoverQuestionProps from './useCoverQuestionProps';
import useOpenTextInputProps from './useOpenTextInputProps';
import useNextQuestionButtonProps from './useNextQuestionButtonProps';
import usePreviousQuestionButtonProps from './usePreviousQuestionButtonProps';
import useAddToFavoritesButtonProps from './useAddToFavoritesButtonProps';
import useSkipQuestionButtonProps from './useSkipQuestionButtonProps';
const usePropsGetters = (quizEvents, quizApiState, quizLocalState, favoriteItems) => {
    const { quizAnswerChanged, nextQuestion, skipQuestion, previousQuestion, resetQuiz, hydrateQuiz, addToCart, addToFavorites, resultClick, } = quizEvents;
    const getOpenTextInputProps = useOpenTextInputProps(quizAnswerChanged, nextQuestion, quizApiState.quizCurrentQuestion?.next_question, quizLocalState.answerInputs);
    const getCoverQuestionProps = useCoverQuestionProps(quizAnswerChanged, quizApiState.quizCurrentQuestion?.next_question);
    const getSelectInputProps = useSelectInputProps(quizAnswerChanged, nextQuestion, quizApiState.quizCurrentQuestion?.next_question, quizLocalState.answerInputs);
    const getNextQuestionButtonProps = useNextQuestionButtonProps(nextQuestion, quizApiState, quizLocalState);
    const getSkipQuestionButtonProps = useSkipQuestionButtonProps(skipQuestion, quizApiState);
    const getPreviousQuestionButtonProps = usePreviousQuestionButtonProps(quizApiState, previousQuestion);
    const getResetQuizButtonProps = useCallback((stylesType = 'primary') => ({
        className: stylesType === 'primary' ? 'cio-question-cta-button' : 'cio-question-redo-button',
        type: 'button',
        onClick: () => resetQuiz(),
    }), [resetQuiz]);
    const getShareResultsButtonProps = useCallback(() => ({ className: 'cio-question-share-results-button' }), []);
    const getHydrateQuizButtonProps = useCallback(() => ({
        className: '',
        type: 'button',
        onClick: () => hydrateQuiz(),
    }), [hydrateQuiz]);
    const getAddToCartButtonProps = useCallback((result, price) => ({
        className: 'cio-result-card-cta-button',
        type: 'button',
        onClick: (e) => addToCart(e, result, price),
    }), [addToCart]);
    const getAddToFavoritesButtonProps = useAddToFavoritesButtonProps(addToFavorites, favoriteItems);
    const quizResultClickDown = useCallback((event, result, position) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            if (resultClick) {
                resultClick(result, position);
            }
        }
    }, [resultClick]);
    const getQuizResultButtonProps = useCallback(({ result, position }) => ({
        className: 'cio-result-card-container',
        role: 'button',
        tabIndex: 0,
        onClick: () => resultClick(result, position),
        onKeyDown: (event) => quizResultClickDown(event, result, position),
    }), [quizResultClickDown, resultClick]);
    const getQuizResultLinkProps = useCallback(({ result, position }) => ({
        href: result.data?.url,
        onClick: () => resultClick(result, position),
        onKeyDown: (event) => quizResultClickDown(event, result, position),
    }), [quizResultClickDown, resultClick]);
    const getQuizImageProps = useCallback(() => ({
        src: quizApiState.quizCurrentQuestion?.next_question?.images?.primary_url || undefined,
        alt: quizApiState.quizCurrentQuestion?.next_question?.images?.primary_alt || undefined,
    }), [quizApiState.quizCurrentQuestion]);
    const getSelectQuestionImageProps = useCallback((option) => ({
        className: 'cio-question-option-image',
        src: option?.images?.primary_url || undefined,
        alt: option?.images?.primary_alt || undefined,
    }), []);
    return {
        getOpenTextInputProps,
        getNextQuestionButtonProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getSelectQuestionImageProps,
        getSelectInputProps,
        getCoverQuestionProps,
        getResetQuizButtonProps,
        getShareResultsButtonProps,
        getHydrateQuizButtonProps,
        getAddToCartButtonProps,
        getAddToFavoritesButtonProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
        getSkipQuestionButtonProps,
    };
};
export default usePropsGetters;
